<?php
if($this->session->userdata('is_logged_in')===FALSE){
            redirect('login');
}


$url = base_url("resources/template/berita_acara/bas_agama/".$blangko_bas_lanjutan_agama.".rtf");

$Template = file_get_contents($url);
//$namakota =str_replace("Pengadilan Agama ",'',$namapn);


$nomor_perkara = $dataperkara->row(0)->nomor_perkara;

$namakota = $datapengadilan->row(0)->NamaPN;
if(substr(ucwords(strtolower($datapengadilan->row(0)->NamaPN)),0,1)=="P"){$jenis_satker="Pengadilan Agama";}else{$jenis_satker="Mahkamah Syar'iah";}
$Template = str_replace("#JENIS_SATKER#",$jenis_satker,$Template);

if($datapersidangan!=''){
    if($datapersidangan->num_rows>0){
        foreach ($datapersidangan->result() as $row) {
            $nextsidang = $idjadwal+1;
            if($nextsidang=$row->urutan){
                $tgl_sidang_tunda = $row->tanggal_sidang;
                $agendatunda = strtolower($row->agenda);
            }
            if($row->id==$idjadwal){
                $tgl_sidang = $row->tanggal_sidang;
            }
        }

        $Template = str_replace("#TGL_SIDANG#", $this->templatehelper->convertKeTglIndo($tgl_sidang) ,$Template);
        $Template = str_replace("#HARI_SIDANG#", $this->templatehelper->getHari($tgl_sidang) ,$Template);
        $Template = str_replace("#TGL_SIDANG_TUNDA#", $this->templatehelper->convertKeTglIndo($tgl_sidang_tunda) ,$Template);
        $Template = str_replace("#HARI_SIDANG_TUNDA#", $this->templatehelper->getHari($tgl_sidang_tunda) ,$Template);
        $Template = str_replace("#AGENDA_TUNDAAN#", $agendatunda ,$Template);
    }
}

$i=0;
$temp_pihak='';
$temp_kuasa='';
$pihak_array='';
foreach ($dataPihak1->result() as $row) {
    if($temp_pihak!=$row->id_pihak){
        $temp_pihak=$row->id_pihak;
        if($i>0){
            $pihak_array = str_replace("#ke#",' '.$this->templatehelper->converToAngkaRomawi($i), $pihak_array);
        }
        
        $pihak_array.=$row->nama.', umur '.$row->umur.' tahun, agama '.$row->agama.
                ', pekerjaan '.$row->pekerjaan.', Pendidikan '.$row->pendidikan.
                ', alamat '.$row->alamat;  
                    
        if($row->id_kuasa!=''){
            if($i>0){$pihak_array= str_replace("#DKK#",'', $pihak_array);}
            $pihak_array.=' dalam hal ini memberikan kuasa khusus kepada '.$row->nama_kuasa.
                ' #DKK# advokat/penasehat hukum dari '.$row->nama.
                ' yang berkantor di '.$row->alamat_kuasa.' berdasarkan surat kuasa khusus tanggal '.$this->templatehelper->convertKeTglIndo($row->tgl_kuasa).
                ' sebagai #SEBAGAI_P##ke#;#par#';            
        }else{
            $pihak_array.=' sebagai #SEBAGAI_P##ke#;#par#';    
        }
        $i++;
    }else{
         $pihak_array = str_replace("#DKK#",'dan kawan kawan', $pihak_array);
    }
}
if($i>1){
    $pihak_array = str_replace("#ke#",' '.$this->templatehelper->converToAngkaRomawi($i), $pihak_array);
    $pihak_array = str_replace("#par#",' \\par ', $pihak_array);
}else{
    $pihak_array = str_replace("#ke#",'', $pihak_array);
    $pihak_array = str_replace("#par#",'', $pihak_array);
}
$pihak_array = str_replace("#DKK#",'', $pihak_array);
$Template = str_replace("#loopingpenggugat#",$pihak_array,$Template);

$i=0;
$temp_pihak='';
$temp_kuasa='';
$pihak_array='';
if ($dataPihak2->num_rows>0) {
	foreach ($dataPihak2->result() as $row) {
	    if($temp_pihak!=$row->id_pihak){
	        $temp_pihak=$row->id_pihak;
	        if($i>0){
	            $pihak_array = str_replace("#ke#",' '.$this->templatehelper->converToAngkaRomawi($i), $pihak_array);
	        }
	        $namapihak2=$row->nama;
	        $pihak_array.=$row->nama.', umur '.$row->umur.' tahun, agama '.$row->agama.
	                ', pekerjaan '.$row->pekerjaan.', Pendidikan '.$row->pendidikan.
	                ', alamat '.$row->alamat;  
	                    
	        if($row->id_kuasa!=''){
	            if($i>0){$pihak_array= str_replace("#DKK#",'', $pihak_array);}
	            $pihak_array.=' dalam hal ini memberikan kuasa khusus kepada '.$row->nama_kuasa.
	                ' #DKK# advokat/penasehat hukum dari '.$row->nama.
	                ' yang berkantor di '.$row->alamat_kuasa.' berdasarkan surat kuasa khusus tanggal '.$this->templatehelper->convertKeTglIndo($row->tgl_kuasa).
	                ' sebagai #SEBAGAI_T##ke#;#par#';            
	        }else{
	            $pihak_array.=' sebagai #SEBAGAI_T##ke#;#par#';    
	        }
	        $i++;
	    }else{
	         $pihak_array = str_replace("#DKK#",'dan kawan kawan', $pihak_array);
	    }
	}
}else{
	$namapihak2='';
}

if($i>1){
    $pihak_array = str_replace("#ke#",' '.$this->templatehelper->converToAngkaRomawi($i), $pihak_array);
    $pihak_array = str_replace("#par#",' \\par ', $pihak_array);
}else{
    $pihak_array = str_replace("#ke#",'', $pihak_array);
    $pihak_array = str_replace("#par#",'', $pihak_array);
}
$pihak_array = str_replace("#DKK#",'', $pihak_array);
$Template = str_replace("#loopingtergugat#",$pihak_array,$Template);


$counter = 1;
$pihak5 = '';
$pihak5_id='';
$arr_pihak5 = array();
$numbering = true;
if($dataPihak5->num_rows >0){
    for ($i=0; $i < $dataPihak5->num_rows; $i++) { 
        $text = 'saksi'.($i+1);
        if($i==$dataPihak5->num_rows-1){
            $Template = str_replace('#loopingsaksi#','#'.$text.'#',$Template);
        }else{
            $Template = str_replace('#loopingsaksi#','#'.$text.'#\\par'.PHP_EOL.'#loopingsaksi#',$Template);
        }
    }   
}else{
    $numbering = false;
    $Template = str_replace('#loopingsaksi#','',$Template);
}

if (!empty($dataPihak5->num_rows)){   
    foreach ($dataPihak5->result() as $row){
        $pihak5_id=$row->id_pihak;
        $arr_pihak5[]=$row->id;
        $nomor=$counter.".";
        $saksi = '\b0\\par ';
        
        $saksi = $saksi;
        $saksi .= ''.$nomor.'\tab '.$this->templatehelper->standradnaming($row->nama).', umur '.$row->umur.' tahun '.', agama '.$row->agama.', pekerjaan '.$row->pekerjaan.', tempat kediaman di '.$row->alamat;

        //$saksi .= '\tab -'.($row->jawaban_t==''?'............' : $row->jawaban_t);

        if($numbering==true){
            $Template = str_replace('#saksi'.$counter.'#',$saksi,$Template);
          
        }else{
           $Template = str_replace('#saksi#',$saksi,$Template);
           $Template = str_replace('#saksi/parasaksi#','Saksi',$Template);
        }
        $counter++;    
    }
}


$i=0;
$penetapan = '';
foreach ($datapenetapanhakim->result() as $row) {
    $i++;
    if($row->jabatan_hakim_id==1){
        $penetapan .=$i.". ".$this->templatehelper->standradnaming($row->nama_gelar)." \\tab "."sebagai ".$row->jabatan_hakim_nama.";\\par".PHP_EOL;
    }elseif($row->jabatan_hakim_id==2){
        $penetapan .=$i.". ".$this->templatehelper->standradnaming($row->nama_gelar)." \\tab "."sebagai ".$row->jabatan_hakim_nama.";";
        if ($row->urutan==2){
            $penetapan.="\\par".PHP_EOL;
        }elseif($row->urutan==3){
            $penetapan.="dan dibantu";
        }
    }elseif($row->jabatan_hakim_id==3){
        if ($datapenetapanhakim->num_rows() >1){
            $penetapan .=$i.". ";  
        }
        $penetapan .=$this->templatehelper->standradnaming($row->nama_gelar)." \\tab "."sebagai ".$row->jabatan_hakim_nama."; dan dibantu";
    }
    $tanggalpenetapanhakim = $this->templatehelper->convertKeTglIndo($row->tanggal_penetapan);
    
}
$Template = str_replace('#majelis#',$penetapan,$Template);

$idperkara=$this->encrypt->decode(base64_decode($enc));
$idalurperkara = $this->tanggalhelper->getIDAlurPerkara($idperkara);
$jenisPerkaraID=$this->tanggalhelper->getIDJenisPerkara($idperkara);

if ($idalurperkara==15) {
    $Template = str_replace("#jenis_perkara#",''." Gugatan ".'',$Template);
    if ($jenisPerkaraID==346) {
        $Template = str_replace("#jenis_pihak1#",''." Pemohon ".'',$Template);
        $Template = str_replace("#jenis_pihak2#",''." Termohon ".'',$Template);
        $Template = str_replace("#SEBAGAI_P#","Pemohon",$Template);
        $Template = str_replace("#SEBAGAI_T#","Termohon",$Template);
    }elseif($blangko_bas_lanjutan_agama=='PDT_15_14_200_8'){
        $Template = str_replace("#jenis_pihak1#",''." Pelawan ".'',$Template);
        $Template = str_replace("#jenis_pihak2#",''." Terlawan ".'',$Template);
        $Template = str_replace("#SEBAGAI_P#","Pelawan",$Template);
        $Template = str_replace("#SEBAGAI_T#","Terlawan",$Template);
    }else{
        $Template = str_replace("#jenis_pihak1#",''." Penggugat ".'',$Template);
        $Template = str_replace("#jenis_pihak2#",''." Tergugat ".'',$Template);
        $Template = str_replace("#SEBAGAI_P#","Penggugat",$Template);
        $Template = str_replace("#SEBAGAI_T#","Tergugat",$Template);
    }
}else{
    $Template = str_replace("#jenis_perkara# ",''." Permohonan ".'',$Template);   
    $Template = str_replace("#jenis_pihak1#",''." Pemohon ".'',$Template);
    $Template = str_replace("#jenis_pihak2#",''." Termohon ".'',$Template);
}

$Template = str_replace("#NAMA_P#",$dataPihak1->row(0)->nama,$Template);
$Template = str_replace("#NAMA_T#",$namapihak2,$Template);
//Pihaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaak

$Template = str_replace("#nomor_perkara#",$dataperkara->row(0)->nomor_perkara,$Template);
$Template = str_replace("#nama_pp#",$this->templatehelper->standradnaming($datapaniterapengganti->row(0)->nama_gelar),$Template);
$Template = str_replace("#hakim_ketua#",$this->templatehelper->standradnaming($datapenetapanhakim->row(0)->nama_gelar),$Template);
$Template = str_replace("#nama_pa#",ucwords(strtolower($datapengadilan->row(0)->NamaPN)),$Template);
$Template = str_replace("#ZONA#",$datapengadilan->row(0)->ZonaWaktu,$Template);
$Template = str_replace("#tglpendaftaran#", $this->templatehelper->convertKeTglIndo($dataperkara->row(0)->tanggal_pendaftaran) ,$Template);
$Template = str_replace("#tglgugatan#", $this->templatehelper->convertKeTglIndo($dataperkara->row(0)->tanggal_surat) ,$Template);
//$Template = str_replace("#amar_putusan#",''.$this->templatehelper->cleanHtmlTagSpecial($dataamar->row(0)->amar_putusan).'',$Template);

if($datapenetapanhakim!=''){
    if($datapenetapanhakim->num_rows>0){
        foreach ($datapenetapanhakim->result() as $row) {
            if(($row->urutan)==1){
                $ketuaMajelis = $row->hakim_nama;
            }
            if(($row->urutan)==2){
                $hakimAnggota1 = $row->hakim_nama;
            }else{
            	$hakimAnggota1 ='';
            }
            if(($row->urutan)==3){
                $hakimAnggota2 = $row->hakim_nama;
            }else{
            	$hakimAnggota2 ='';
            }
        }
        
    }
}
$Template = str_replace("#NAMA_MAJELIS#",''.$ketuaMajelis.'',$Template);
$Template = str_replace("#NAMA_ANGGOTA1#",''.$hakimAnggota1.'',$Template);
$Template = str_replace("#NAMA_ANGGOTA2#",''.$hakimAnggota2.'',$Template);

if($datamediator!=''){
    if($datamediator->num_rows>0){
        foreach ($datamediator->result() as $mediator) {
            $namaMediator = $mediator->mediator_text;
            $hasilmediasi = $mediator->hasil_mediasi;
            $tanggallaporanMediator = $this->templatehelper->convertKeTglIndo($mediator->tgl_laporan_mediator);
            if($hasilmediasi='Y'){
                $hasil='Berhasil'; 
            } else {            
                $hasil='Tidak Berhasil';
            }

        }
        $Template = str_replace("#NAMA_MEDIATOR#",''.$namaMediator.'',$Template);
        $Template = str_replace("#TGL_MEDIASI#",''.$tanggallaporanMediator.'',$Template);
        $Template = str_replace("#HASIL_MEDIASI#",''.$hasil.'',$Template);
    }
}
if($dataputusanverstek!=''){
    if($dataputusanverstek->num_rows>0){
        foreach ($dataputusanverstek->result() as $putusan) {
            $amarPutusan = $this->templatehelper->cleanHtmlTagSpecial($putusan->amar_putusan);
        }        
        $Template = str_replace("#AMARPUTUSAN#",$amarPutusan,$Template);
    }
}

if($dataputusanakhir!=''){
    if($dataputusanakhir->num_rows>0){
        foreach ($dataputusanakhir->result() as $row) {
            $tglPutusanAkhir = $this->templatehelper->convertKeTglIndo($row->tanggal_putusan);
            $amarPutusan = $this->templatehelper->cleanHtmlTagSpecial($row->amar_putusan);
        }
        $Template = str_replace("#TGL_PUTUS#",$tglPutusanAkhir,$Template);
        $Template = str_replace("#AMARPUTUSAN#",$amarPutusan,$Template);
    }
}
if($dataAmarIkrar!=''){
    if($dataAmarIkrar->num_rows>0){
        foreach ($dataAmarIkrar->result() as $row) {
            $tglikrar = $this->templatehelper->convertKeTglIndo($row->tgl_ikrar_talak);
            $hariikrar = $this->templatehelper->getHari($row->tgl_ikrar_talak);
            $amarikrar = $this->templatehelper->cleanHtmlTagSpecial($row->amar_ikrar_talak);
            $tgl_ikrarselaHijriah = $this->templatehelper->convertToHijriah($row->tgl_ikrar_talak);
        }
        $Template = str_replace("#TGL_IKRAR#",$tglikrar,$Template);
        $Template = str_replace("#HARI_IKRAR#",$hariikrar,$Template);
        $Template = str_replace("#AMARIKRAR#",$amarikrar,$Template);
        $Template = str_replace("#TGL_IKRAR_HIJRIAH#",$tgl_ikrarselaHijriah,$Template);
    }
}
if($dataputusansela!=''){
    if($dataputusansela->num_rows>0){
        foreach ($dataputusansela->result() as $sela) {
            $amarPutusansela = $this->templatehelper->cleanHtmlTagSpecial($sela->amar_sela);
            $tgl_putusansela = $this->templatehelper->convertKeTglIndo($sela->tanggal_putusan_sela);
            $hari_putusansela = $this->templatehelper->getHari($sela->tanggal_putusan_sela);
            $tgl_putusanselaHijriah = $this->templatehelper->convertToHijriah($sela->tanggal_putusan_sela);
        }
        $Template = str_replace("#PENETAPANSELA#",''.$amarPutusansela.'',$Template);
        $Template = str_replace("#TANGGALSELA#",''.$tgl_putusansela.'',$Template);
        $Template = str_replace("#HARISELA#",''.$hari_putusansela.'',$Template);
        $Template = str_replace("#TGL_HIJRIAH#",''.$tgl_putusanselaHijriah.'',$Template);
    }
}

$temp = explode(' ', ($datapengadilan->row(0)->NamaPN));
$Template = str_replace("#pa/ms#",''. ucwords(strtolower($temp[0].' '. $temp[1])).'',$Template);

$Template = str_replace("#tgl_pendaftaran#", $this->templatehelper->convertKeTglIndo($dataperkara->row(0)->tanggal_pendaftaran) ,$Template);//ditaro bawah supaya sebagainya bisa di replace kembali

header("Content-Type: application/vnd.ms-word");
header("Expires: 0");
header("Cache-Control:  must-revalidate, post-check=0, pre-check=0");
header("Content-disposition: attachment; filename=\"BAS_Lanjutan-$nomor_perkara-$tgl_sidang.rtf\"");
echo $Template;
?>